#
# spec file for package gputils
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gputils
Version:        1.5.2
Release:        2.3
Summary:        Development utilities for Microchip PIC microcontrollers
License:        GPL-2.0-or-later
Group:          Development/Tools/Other
URL:            http://gputils.sourceforge.net
Source:         https://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE gputils-no-build-time.patch -- fix W: file-contains-current-date
Patch1:         gputils-no-build-time.patch
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  make

%description
This is a collection of development tools for Microchip PIC
microcontrollers.

Gputils implements a subset of features available with Microchip's tools.
See the documentation for an up-to-date list of what gputils can do.

%package        doc
Summary:        Documentation files for PIC MCUs
Group:          Documentation/Other
Requires:       %{name} = %{version}
%if 0%{?suse_version} >= 1140
BuildArch:      noarch
%endif

%description doc
Documentation for gputils and supported PIC MCUs.

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install

%fdupes %{buildroot}

# documentation
install -d %{buildroot}%{_docdir}/%{name}
mv %{buildroot}%{_datadir}/doc/%{name}-%{version}/html %{buildroot}%{_docdir}/%{name}
rm -r %{buildroot}%{_datadir}/doc/%{name}-%{version}
install -Dm 644 doc/gputils.pdf %{buildroot}%{_docdir}/%{name}

%files
%{_bindir}/gpasm
%{_bindir}/gpdasm
%{_bindir}/gplib
%{_bindir}/gplink
%{_bindir}/gpstrip
%{_bindir}/gpvc
%{_bindir}/gpvo
%{_mandir}/man1/*
%{_mandir}/fr/man1/*
%{_datadir}/gputils
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%exclude %{_docdir}/%{name}/html/
%exclude %{_docdir}/%{name}/gputils.pdf

%if 0%{?suse_version} >= 1200
%files doc
%{_docdir}/%{name}/html/
%{_docdir}/%{name}/gputils.pdf
%endif

%changelog
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Sat Jul 23 2022 Dirk Müller <dmueller@suse.com>
- update to 1.5.2:
  * Fix Parser doesn't allow more than one unary operator
  * Fixed bug: "#318 ELIF is not ELSE IF, bug or unusual name?"
  * Fixed bug: "#314 PIC16F69 TRIS does not assemble correctly"
  * Fixed bug: "#315 gpasm allows RETURN for 10F202"
* Sat Oct 22 2016 jengelh@inai.de
- trim TM marks
* Mon Oct 10 2016 wk@ire.pw.edu.pl
- updated to 1.5.0-1
- gputils-no-build-time.patch updated
* Sun Jan  3 2016 wk@ire.pw.edu.pl
- updated to 1.4.2
- gputils-no-build-time.patch updated
* Thu Nov 27 2014 wk@ire.pw.edu.pl
- updated to 1.4.0-1
* Mon Jul 28 2014 dmitry_r@opensuse.org
- spec file cleanup
- Delete build time from binaries
  * gputils-no-build-time.patch
* Sun Jun  1 2014 wk@ire.pw.edu.pl
- updated to 1.3.0
* Sun May 26 2013 Wojciech Kazubski wk@ire.pw.edu.pl - 1.2.0-1
- updated to 1.2.0
* Sat Mar 30 2013 Wojciech Kazubski wk@ire.pw.edu.pl - 1.1.0-1
- updated to 1.1.0
* Sat Feb  2 2013 Wojciech Kazubski wk@ire.pw.edu.pl - 1.0.0-1
- updated to 1.0.0
* Sat Dec  1 2012 Wojciech Kazubski wk@ire.pw.edu.pl - 0.15.0-1
- updated to 0.15.0
- fixed build on SLE10
* Fri Nov  2 2012 Wojciech Kazubski wk@ire.pw.edu.pl - 0.14.3-26
- fixed build on SLE11
* Wed Oct 31 2012 Wojciech Kazubski wk@ire.pw.edu.pl - 0.14.3-22
- updated to 0.14.3
- fixed some warnings reported by rpmlint
* Mon Sep  3 2012 Wojciech Kazubski wk@ire.pw.edu.pl
- update to 0.14.2
* Tue Jun 12 2012 cyberorg@opensuse.org
- update to 0.14.2_RC1
  Wed Jan 13 2010 Torben Mikael Hansen - build at sciomnis__singledot__com
- Version 0.13.7
